==> vtk-8.0.1-4-aarch64.pkg.tar.xz: vtk/vtkOpenGLRenderPass.java <==
// java wrapper for vtkOpenGLRenderPass object
//

package vtk;
import vtk.*;

public class vtkOpenGLRenderPass extends vtkRenderPass
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean PreReplaceShaderValues_2(String id0,String id1,String id2,vtkAbstractMapper id3,vtkProp id4);
  public boolean PreReplaceShaderValues(String id0,String id1,String id2,vtkAbstractMapper id3,vtkProp id4)
    { return PreReplaceShaderValues_2(id0,id1,id2,id3,id4); }

  private native boolean PostReplaceShaderValues_3(String id0,String id1,String id2,vtkAbstractMapper id3,vtkProp id4);
  public boolean PostReplaceShaderValues(String id0,String id1,String id2,vtkAbstractMapper id3,vtkProp id4)
    { return PostReplaceShaderValues_3(id0,id1,id2,id3,id4); }

  private native int GetShaderStageMTime_4();
  public int GetShaderStageMTime()
    { return GetShaderStageMTime_4(); }

  private native long RenderPasses_5();
  public vtkInformationObjectBaseVectorKey RenderPasses() {
    long temp = RenderPasses_5();

    if (temp == 0) return null;
    return (vtkInformationObjectBaseVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetActiveDrawBuffers_6(int id0);
  public void SetActiveDrawBuffers(int id0)
    { SetActiveDrawBuffers_6(id0); }

  private native int GetActiveDrawBuffers_7();
  public int GetActiveDrawBuffers()
    { return GetActiveDrawBuffers_7(); }

  public vtkOpenGLRenderPass() { super(); }

  public vtkOpenGLRenderPass(long id) { super(id); }

}

==> vtk-8.2.0-1-aarch64.pkg.tar.xz: vtk/vtkOpenGLRenderPass.java <==
// java wrapper for vtkOpenGLRenderPass object
//

package vtk;
import vtk.*;

public class vtkOpenGLRenderPass extends vtkRenderPass
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean PreReplaceShaderValues_2(String id0,String id1,String id2,vtkAbstractMapper id3,vtkProp id4);
  public boolean PreReplaceShaderValues(String id0,String id1,String id2,vtkAbstractMapper id3,vtkProp id4)
    { return PreReplaceShaderValues_2(id0,id1,id2,id3,id4); }

  private native boolean PostReplaceShaderValues_3(String id0,String id1,String id2,vtkAbstractMapper id3,vtkProp id4);
  public boolean PostReplaceShaderValues(String id0,String id1,String id2,vtkAbstractMapper id3,vtkProp id4)
    { return PostReplaceShaderValues_3(id0,id1,id2,id3,id4); }

  private native boolean SetShaderParameters_4(vtkShaderProgram id0,vtkAbstractMapper id1,vtkProp id2,vtkOpenGLVertexArrayObject id3);
  public boolean SetShaderParameters(vtkShaderProgram id0,vtkAbstractMapper id1,vtkProp id2,vtkOpenGLVertexArrayObject id3)
    { return SetShaderParameters_4(id0,id1,id2,id3); }

  private native int GetShaderStageMTime_5();
  public int GetShaderStageMTime()
    { return GetShaderStageMTime_5(); }

  private native long RenderPasses_6();
  public vtkInformationObjectBaseVectorKey RenderPasses() {
    long temp = RenderPasses_6();

    if (temp == 0) return null;
    return (vtkInformationObjectBaseVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetActiveDrawBuffers_7(int id0);
  public void SetActiveDrawBuffers(int id0)
    { SetActiveDrawBuffers_7(id0); }

  private native int GetActiveDrawBuffers_8();
  public int GetActiveDrawBuffers()
    { return GetActiveDrawBuffers_8(); }

  public vtkOpenGLRenderPass() { super(); }

  public vtkOpenGLRenderPass(long id) { super(id); }

}
